# Copyright (c) Istituto Nazionale di Fisica Nucleare (INFN). 2006-2010.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

%define name         storm-pre-assembled-configuration
%define version      1.1.0
%define release      8

%define builddir     @RPM_BUILD_DIR@/build-%{name}-%{version}

%define default_user root

Name:           %{name}
Version:        %{version}
Release:        %{release}%{?dist}
Vendor:         EMI
Packager:       Elisabetta Ronchieri <elisabetta.ronchieri@cnaf.infn.it>
License:        Apache License
URL:            http://grid-it.cnaf.infn.it
Source:         storm-pre-assembled-configuration-%{version}.tar.gz
Group:          System Environment/Shells
AutoReqProv:    yes
BuildArch:      noarch
BuildRoot:      %{_builddir}/var/tmp/%{name}-%{version}
Summary:        Provides the utility files. 

%define _sysconfdir    /etc
%define _generalprefix storm

BuildRequires: libtool
BuildRequires: automake
BuildRequires: autoconf

%define debug_package %{nil}

%description
This contains information to configure StoRM nodes.

%prep
%setup -n storm-pre-assembled-configuration-%{version}

%build
./bootstrap
./configure --prefix=/usr --sbindir=/usr/sbin --datadir=/usr/share --sysconfdir=/etc
make

%pre
rm -rf /tmp/storm_permissions_mantainance
if [ -d %{_sysconfdir}/%{_generalprefix} ] ; then
    STORM_CONF_OWNNER_USER=`stat -c %U %{_sysconfdir}/%{_generalprefix}`
    STORM_CONF_OWNNER_GROUP=`stat -c %G %{_sysconfdir}/%{_generalprefix}`
    if [ ! "x${STORM_CONF_OWNNER_USER}" = "x%{default_user}" ] ; then
        echo "preserving %{_sysconfdir}/%{_generalprefix} folder owner ownership"
        umask 077 && mkdir -p /tmp/storm_permissions_mantainance
        echo "export STORM_CONF_OWNNER_USER=${STORM_CONF_OWNNER_USER}" >> /tmp/storm_permissions_mantainance/export_vars
        echo "unset STORM_CONF_OWNNER_USER" >> /tmp/storm_permissions_mantainance/unset_vars
    fi
    if [ ! "x${STORM_CONF_OWNNER_GROUP}" = "x%{default_user}" ] ; then
        echo "preserving %{_sysconfdir}/%{_generalprefix} folder group ownership"
        echo "export STORM_CONF_OWNNER_GROUP=${STORM_CONF_OWNNER_GROUP}" >> /tmp/storm_permissions_mantainance/export_vars
        echo "unset STORM_CONF_OWNNER_GROUP" >> /tmp/storm_permissions_mantainance/unset_vars
    fi
fi

%post
if [ -d %{_sysconfdir}/%{_generalprefix} ] ; then
    if [ -d /tmp/storm_permissions_mantainance ] ; then
        echo "restoring %{_sysconfdir}/%{_generalprefix} and %{_varlog}/%{_generalprefix} folder ownership"
        if [ -f /tmp/storm_permissions_mantainance/export_vars -a -f /tmp/storm_permissions_mantainance/unset_vars ] ; then
            source /tmp/storm_permissions_mantainance/export_vars
            DONE="false"
                if [ ! -z ${STORM_CONF_OWNNER_USER} ] ; then
                    echo "Setting %{_sysconfdir}/%{_generalprefix} user ownership to ${STORM_CONF_OWNNER_USER}"
                    chown ${STORM_CONF_OWNNER_USER} %{_sysconfdir}/%{_generalprefix}
                    DONE="true"
                fi
                if [ ! -z ${STORM_CONF_OWNNER_GROUP} ] ; then
                    echo "Setting %{_sysconfdir}/%{_generalprefix} group ownership to ${STORM_CONF_OWNNER_GROUP}"
                    chgrp ${STORM_CONF_OWNNER_GROUP} %{_sysconfdir}/%{_generalprefix}
                    DONE="true"
                fi
            source /tmp/storm_permissions_mantainance/unset_vars
            DONE=""
        else
            echo "Error. No env variable files available in /tmp/storm_permissions_mantainance"
            exit 1
        fi
        rm -rf /tmp/storm_permissions_mantainance
    fi
fi

%install
if [ -d $RPM_BUILD_ROOT ]; then rm -rf $RPM_BUILD_ROOT; fi
mkdir -p $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files 
%defattr(-,%{default_user},%{default_user},-)

%{_sbindir}/EMI_1_repos_install
%config %attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/storm.def
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/storm.def.template
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/storm-users.conf
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/storm-groups.conf
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/storm-wn-list.conf
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/vo.d/dteam
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/vo.d/infngrid
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/vo.d/ops
%attr(750,%{default_user},%{default_user}) %{_sysconfdir}/%{_generalprefix}/siteinfo/vo.d/testers.eu-emi.eu
%doc %{_datadir}/doc/%{name}-%{version}/AUTHORS
%doc %{_datadir}/doc/%{name}-%{version}/ChangeLog
%doc %{_datadir}/doc/%{name}-%{version}/CREDITS
%doc %{_datadir}/doc/%{name}-%{version}/LICENSE
%doc %{_datadir}/doc/%{name}-%{version}/README

%dir %{_datadir}/doc/%{name}-%{version}
%dir %{_sysconfdir}/%{_generalprefix}
%dir %{_sysconfdir}/%{_generalprefix}/siteinfo
%dir %{_sysconfdir}/%{_generalprefix}/siteinfo/vo.d

%changelog

* Thu Dec 15 2011 Elisabetta Ronchieri <elisabetta.ronchieri@cnaf.infn.it> - 1.0.0-1.sl5
- pre assembled configuartion contains information to configure storm nodes

